@@ -8,13 +8,27 @@
 # @Software: PyCharm
 # @Desc    :
 import json
+import time
 
 import requests
-from ..queue_service.context import Context
-from .. import SAVE_TO_LOG_CENTER_URL
+# from ys_service.queue_service.context import Context
+SAVE_TO_LOG_CENTER_URL = "http://192.168.0.212:8081/log/save"
+# from ys_service import SAVE_TO_LOG_CENTER_URL
+from datetime import datetime, timezone, timedelta
 
 
-def send_to_log_center(context: Context, project, module, user, return_msg, level, *args):
+def get_time():
+    """
+    获取当前东8区的时间字符串
+    :return:
+    """
+    now = datetime.utcnow().replace(tzinfo=timezone.utc)
+    now_zone8 = now.astimezone(timezone(timedelta(hours=8)))
+
+    return now_zone8.isoformat()
+
+
+def send_to_log_center(context, project, module, user, return_msg, level, **kwargs):
     """
     send msg to log_center
     :param context:
@@ -23,15 +37,15 @@ def send_to_log_center(context: Context, project, module, user, return_msg, leve
     :param user:
     :param return_msg:
     :param level:
-    :param args: field1, field2, field3, field4, field5
+    :param kwargs: field1, field2, field3, field4, field5
     :return:
     """
 
     # 数据组成
     msg_data = {
-        "queue_name": context.queue.queue_name,
-        "input_parameters": context.text,
-        "return_msg": return_msg
+        "队列名称": context.queue.queue_name,
+        "传入数据:": context.text,
+        "返回数据": return_msg
     }
     # 请求数据
     request_data = {
@@ -40,10 +54,9 @@ def send_to_log_center(context: Context, project, module, user, return_msg, leve
         "level": level,
         "user": user,
         "message": json.dumps(msg_data, ensure_ascii=False),
+        "time": get_time()
     }
-
-    for k, arg in enumerate(args):
-        request_data["field" + str(k+1)] = arg
+    request_data.update(kwargs)
 
     r = requests.post(SAVE_TO_LOG_CENTER_URL, json=request_data)
     return r.text
